# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKOptimizersv4Python



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkLBFGSOptimizerv4Python
else:
    import _itkLBFGSOptimizerv4Python

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkPointPython
import itk.itkObjectToObjectMetricBasePython
import itk.itkOptimizerParametersPython
import itk.itkArrayPython
import itk.itkSingleValuedCostFunctionv4Python
import itk.itkCostFunctionPython
import itk.itkLBFGSOptimizerBaseHelperv4Python
import itk.itkLBFGSOptimizerBasev4Python
import itk.itkSingleValuedNonLinearVnlOptimizerv4Python
import itk.itkObjectToObjectOptimizerBasePython
import itk.itkOptimizerParameterScalesEstimatorPython
import itk.itkVnlTypesPython
import itk.vnl_cost_functionPython
import itk.vnl_unary_functionPython
class itkLBFGSOptimizerv4_Superclass(itk.itkSingleValuedNonLinearVnlOptimizerv4Python.itkSingleValuedNonLinearVnlOptimizerv4):
    r"""Proxy of C++ itkLBFGSOptimizerv4_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOptimizer(self):
        r"""GetOptimizer(self) -> itkLBFGSOptimizerBaseHelperv4vnl_lbfgs"""
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_Superclass_GetOptimizer(self)

    def StartOptimization(self, doOnlyInitialization=False):
        r"""
        StartOptimization(self, doOnlyInitialization=False)

        Parameters
        ----------
        doOnlyInitialization: bool

        """
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_Superclass_StartOptimization(self, doOnlyInitialization)

    def SetTrace(self, flag):
        r"""
        SetTrace(self, flag)

        Parameters
        ----------
        flag: bool

        """
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_Superclass_SetTrace(self, flag)

    def GetTrace(self):
        r"""GetTrace(self) -> bool"""
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_Superclass_GetTrace(self)

    def TraceOn(self):
        r"""TraceOn(self)"""
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_Superclass_TraceOn(self)

    def TraceOff(self):
        r"""TraceOff(self)"""
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_Superclass_TraceOff(self)

    def SetMaximumNumberOfFunctionEvaluations(self, n):
        r"""
        SetMaximumNumberOfFunctionEvaluations(self, n)

        Parameters
        ----------
        n: unsigned int

        """
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_Superclass_SetMaximumNumberOfFunctionEvaluations(self, n)

    def GetMaximumNumberOfFunctionEvaluations(self):
        r"""GetMaximumNumberOfFunctionEvaluations(self) -> unsigned int"""
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_Superclass_GetMaximumNumberOfFunctionEvaluations(self)

    def SetGradientConvergenceTolerance(self, f):
        r"""
        SetGradientConvergenceTolerance(self, f)

        Parameters
        ----------
        f: double

        """
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_Superclass_SetGradientConvergenceTolerance(self, f)

    def GetGradientConvergenceTolerance(self):
        r"""GetGradientConvergenceTolerance(self) -> double"""
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_Superclass_GetGradientConvergenceTolerance(self)
    __swig_destroy__ = _itkLBFGSOptimizerv4Python.delete_itkLBFGSOptimizerv4_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLBFGSOptimizerv4_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_Superclass_cast(obj)

# Register itkLBFGSOptimizerv4_Superclass in _itkLBFGSOptimizerv4Python:
_itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_Superclass_swigregister(itkLBFGSOptimizerv4_Superclass)

def itkLBFGSOptimizerv4_New():
    return itkLBFGSOptimizerv4.New()

class itkLBFGSOptimizerv4(itkLBFGSOptimizerv4_Superclass):
    r"""Proxy of C++ itkLBFGSOptimizerv4 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLBFGSOptimizerv4_Pointer"""
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLBFGSOptimizerv4_Pointer"""
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_Clone(self)

    def StartOptimization(self, doOnlyInitialization=False):
        r"""
        StartOptimization(self, doOnlyInitialization=False)

        Parameters
        ----------
        doOnlyInitialization: bool

        """
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_StartOptimization(self, doOnlyInitialization)

    def VerboseOn(self):
        r"""VerboseOn(self)"""
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_VerboseOn(self)

    def VerboseOff(self):
        r"""VerboseOff(self)"""
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_VerboseOff(self)

    def SetLineSearchAccuracy(self, f):
        r"""
        SetLineSearchAccuracy(self, f)

        Parameters
        ----------
        f: double

        """
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_SetLineSearchAccuracy(self, f)

    def GetLineSearchAccuracy(self):
        r"""GetLineSearchAccuracy(self) -> double"""
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_GetLineSearchAccuracy(self)

    def SetDefaultStepLength(self, f):
        r"""
        SetDefaultStepLength(self, f)

        Parameters
        ----------
        f: double

        """
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_SetDefaultStepLength(self, f)

    def GetDefaultStepLength(self):
        r"""GetDefaultStepLength(self) -> double"""
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_GetDefaultStepLength(self)
    __swig_destroy__ = _itkLBFGSOptimizerv4Python.delete_itkLBFGSOptimizerv4

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLBFGSOptimizerv4

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLBFGSOptimizerv4

        Create a new object of the class itkLBFGSOptimizerv4 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLBFGSOptimizerv4.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLBFGSOptimizerv4.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLBFGSOptimizerv4.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLBFGSOptimizerv4 in _itkLBFGSOptimizerv4Python:
_itkLBFGSOptimizerv4Python.itkLBFGSOptimizerv4_swigregister(itkLBFGSOptimizerv4)

